@@ -104,6 +104,21 @@ int suite_vce_tests_clean();
  */
 extern CU_TestInfo vce_tests[];
 
+/**
++ * Initialize vcn test suite
++ */
+int suite_vcn_tests_init();
+
+/**
++ * Deinitialize vcn test suite
++ */
+int suite_vcn_tests_clean();
+
+/**
++ * Tests in vcn test suite
++ */
+extern CU_TestInfo vcn_tests[];
+
 /**
  * Helper functions
  */
